@@ -21,6 +21,7 @@
 #include <QObject>
 #include <QVector>
 #include "pimcommon_export.h"
+#include "pluginutil.h"
 
 namespace PimCommon
 {
@@ -30,6 +31,20 @@ class PIMCOMMON_EXPORT GenericPluginManager : public QObject
 {
     Q_OBJECT
 public:
+    class GenericPluginData
+    {
+    public:
+        GenericPluginData()
+            : mEnableByDefault(false)
+        {
+
+        }
+        QString mDescription;
+        QString mName;
+        QString mIdentifier;
+        bool mEnableByDefault;
+    };
+
     explicit GenericPluginManager(QObject *parent = Q_NULLPTR);
     ~GenericPluginManager();
 
@@ -44,6 +59,13 @@ public:
     static GenericPluginManager *self();
 
     QVector<PimCommon::GenericPlugin *> pluginsList() const;
+    QVector<PimCommon::PluginUtilData> pluginsDataList() const;
+
+    QString configGroupName() const;
+    QString configPrefixSettingKey() const;
+
+    GenericPlugin *pluginFromIdentifier(const QString &id);
+
 private:
     GenericPluginManagerPrivate *const d;
 };
